@@ -451,57 +451,6 @@ class ConfigWrapper(object):
         return self.pyrax_connection
 
 
-    def verify_config_file(self):
-
-        """
-        This makes sure a bunch of fields are defined in the config
-        file.
-
-        It doesn't verify the data is correct.  It just verifies
-        it exists.
-
-        Returns self if file is A-OK, otherwise, raises a MissingConfig
-        exception on the first missing value.
-        """
-
-        # We could make the "important_properties" list dynamically.
-        # We could write our own decorator named "important_property"
-        # that we used instead of the regular property decorator.
-        # "important_property" would do the same thing as the regular
-        # property decorator, but it would also append the particular
-        # property to a class-level (not instance level!) array
-        # attribute.
-
-        # In fact, that's what should be done.  So, please do it.
-
-        important_properties = [
-            'database_port',
-            'database_name',
-            'database_host',
-            'database_user',
-            'database_password',
-            'pyrax_username',
-            'pyrax_api_key',
-            'smtp_host',
-            'web_host',
-        ]
-
-        log.debug('Verifying config file contents:')
-
-        for propname in important_properties:
-
-            log.debug('{0}: {1}'.format(
-                propname,
-                getattr(self, propname)))
-
-        # This else clause fires in the event that the for-loop
-        # completed.  Weird, right?  The only way to not go into the else
-        # clause below is to use a break statement.
-
-        else:
-            log.info("Config file contains all required data")
-            return self
-
     def connect_everything(self):
 
         """
@@ -529,7 +478,6 @@ class ConfigWrapper(object):
 
         self.set_as_default()
         self.configure_logging()
-        self.verify_config_file()
 
         if self.production_mode:
             self.run_production_mode_stuff()
@@ -540,6 +488,11 @@ class ConfigWrapper(object):
         return self.dispatcher_class(j, pgconn, self)
 
     def run_production_mode_stuff(self):
+
+        """
+        Subclasses can add stuff in here if they want.
+        """
+
         log.info("Nothing to do for production-mode stuff")
 
     @abc.abstractproperty
