@@ -6,7 +6,6 @@ import datetime
 import importlib
 import inspect
 import logging
-import pdb
 import sys
 import warnings
 import traceback
@@ -38,29 +37,27 @@ class Dispatcher(object):
 
         raise NotImplementedError
 
+    @abc.abstractproperty
+    def error_page(self):
+
+        raise NotImplementedError
 
 
-    def __init__(self, jinja2_environment, dbconn, config_wrapper):
+    def __init__(self, jinja2_environment, pgconn, config_wrapper):
 
         self.jinja2_environment = jinja2_environment
-        self.dbconn = dbconn
+        self.pgconn = pgconn
         self.config_wrapper = config_wrapper
 
         self.handlers = []
         self.make_handlers()
 
-        self.error_page = self.jinja2_environment.get_template(
-            'framework_templates/error.html')
-
         log.info("Dispatcher __init__ complete!  Framework is ready.")
 
     @property
     def cw(self):
         return self.config_wrapper
 
-    @property
-    def pgconn(self):
-        return self.dbconn
 
     def __call__(self, environ, start_response):
 
@@ -72,7 +69,10 @@ class Dispatcher(object):
 
         try:
 
-            req = self.request_class(self.dbconn, self.config_wrapper, environ)
+            req = self.request_class(
+                self.pgconn,
+                self.config_wrapper,
+                environ)
 
             # TODO: Figure out if there is some more elegant approach to
             # making the request object visible in the template.
@@ -109,7 +109,7 @@ class Dispatcher(object):
                 new_expires_time = req.session.maybe_update_session_expires_time(
                     self.pgconn)
 
-            self.dbconn.commit()
+            self.pgconn.commit()
 
             start_response(resp.status, resp.headers)
 
@@ -122,7 +122,7 @@ class Dispatcher(object):
 
         except Exception, ex:
 
-            self.dbconn.rollback()
+            self.pgconn.rollback()
             log.critical(ex, exc_info=1)
 
             if self.cw.launch_debugger_on_error:
@@ -241,24 +241,6 @@ class Dispatcher(object):
             log.critical(ex, exc_info=1)
             raise
 
-    def make_handler(self, s):
-
-        """
-        Don't get this confused with the other method named
-        make_handlers!
-        """
-
-        # TODO: rename this to something that won't be confused with
-        # make_handlers.
-
-        cls = self.convert_string_to_class(s)
-
-        return cls(
-            self.jinja2_environment,
-            self.dbconn,
-            self.config_wrapper,
-            self)
-
 
     @staticmethod
     def convert_string_to_class(s):
